@@ -53,8 +53,7 @@ use std::borrow::Cow;
 /// # use extract_frontmatter::config::Splitter;
 /// # use extract_frontmatter::Extractor;
 /// # let input = include_str!("../resources/examples/example1.md");
-/// let (front_matter, data) = Extractor::new(Splitter::DelimiterLine(String::from("+++")))
-///     .extract(input);
+/// let (front_matter, data) = Extractor::new(Splitter::DelimiterLine("+++")).extract(input);
 /// # assert_eq!(front_matter.trim(), include_str!("../resources/examples/example1-meta.toml").trim());
 /// # assert_eq!(data.trim(), include_str!("../resources/examples/example1-data.md").trim());
 /// ```
@@ -98,8 +97,8 @@ use std::borrow::Cow;
 /// # use extract_frontmatter::config::{Modifier, Splitter};
 /// # use extract_frontmatter::Extractor;
 /// # let input = include_str!("../resources/examples/example2.sql");
-/// let (front_matter, data) = Extractor::new(Splitter::LinePrefix(String::from("-- ")))
-///     .with_modifier(Modifier::StripPrefix(String::from("-- ")))
+/// let (front_matter, data) = Extractor::new(Splitter::LinePrefix("-- "))
+///     .with_modifier(Modifier::StripPrefix("-- "))
 ///     .extract(input);
 /// # assert_eq!(front_matter.trim(), include_str!("../resources/examples/example2-meta.yml").trim());
 /// # assert_eq!(data.trim(), include_str!("../resources/examples/example2-data.sql").trim());
@@ -121,20 +120,20 @@ use std::borrow::Cow;
 /// SELECT version();
 /// ```
 #[derive(Debug)]
-pub struct Extractor {
-    splitter: Splitter,
-    modifiers: Vec<Modifier>,
+pub struct Extractor<'opt> {
+    splitter: Splitter<'opt>,
+    modifiers: Vec<Modifier<'opt>>,
 }
 
-impl Extractor {
+impl<'opt> Extractor<'opt> {
     /// Instantiate a new [`Extractor`] config.
     #[must_use]
-    pub const fn new(splitter: Splitter) -> Self {
+    pub const fn new(splitter: Splitter<'opt>) -> Self {
         Self { splitter, modifiers: Vec::new() }
     }
 
     /// Add a modifier to the front-matter returned by [`.extract()`](Self::extract).
-    pub fn with_modifier(&mut self, modifier: Modifier) -> &mut Self {
+    pub fn with_modifier(&mut self, modifier: Modifier<'opt>) -> &mut Self {
         self.modifiers.push(modifier);
 
         self
@@ -148,8 +147,8 @@ impl Extractor {
     pub fn extract<'input>(&self, input: &'input str) -> (Cow<'input, str>, &'input str) {
         let (meta, data) = match self.splitter {
             Splitter::LineIndex(index) => extract_by_line_index(input, index),
-            Splitter::DelimiterLine(ref delim) => extract_by_delimiter_line(input, delim),
-            Splitter::LinePrefix(ref prefix) => extract_by_line_prefix(input, prefix),
+            Splitter::DelimiterLine(delim) => extract_by_delimiter_line(input, delim),
+            Splitter::LinePrefix(prefix) => extract_by_line_prefix(input, prefix),
         };
 
         let mut meta = Cow::from(meta);
