@@ -5,8 +5,8 @@ use extract_frontmatter::Extractor;
 
 #[test]
 fn markdown_with_toml() {
-    let (actual_meta, actual_data) = Extractor::new(Splitter::DelimiterLine(String::from("+++")))
-        .extract(include_str!("../resources/examples/example1.md"));
+    let (actual_meta, actual_data) =
+        Extractor::new(Splitter::DelimiterLine("+++")).extract(include_str!("../resources/examples/example1.md"));
 
     assert_eq!(
         (actual_meta.trim(), actual_data.trim()),
@@ -19,8 +19,8 @@ fn markdown_with_toml() {
 
 #[test]
 fn sql_with_yaml() {
-    let (actual_meta, actual_data) = Extractor::new(Splitter::LinePrefix(String::from("-- ")))
-        .with_modifier(Modifier::StripPrefix(String::from("-- ")))
+    let (actual_meta, actual_data) = Extractor::new(Splitter::LinePrefix("-- "))
+        .with_modifier(Modifier::StripPrefix("-- "))
         .extract(include_str!("../resources/examples/example2.sql"));
 
     assert_eq!(
